from typing import List


def two_sum(nums: List[int], target: int) -> List[int]:
    """
    Given an array of integers nums and an integer target,
    return indices of the two numbers such that they add up to target.
    Elements can only be used once.
    You can return the answer in any order.

    Args:
        nums (list): array of integers
        target (int): target number that two integers should sum up to

    Returns:
        list: indices from initial list that add up to target.
    """
    nums_range = range(len(nums))
    for i in nums_range:
        for j in [x for x in nums_range if x != i]:
            if nums[i] + nums[j] == target:
                return [i, j]
    raise ValueError("Impossible to obtain %s with %s", target, nums)



import pytest

from reticulok.leetcode.easy import *


def test_two_sum_correct():
    assert two_sum([1, 2, 4], 6) == [1, 2]


def test_two_sum_exception():
    with pytest.raises(ValueError):
        two_sum([1, 2, 4], 10)



def int_to_roman(num: int) -> str:
    """
    Convert an integer to a Roman numeral.
    This method is only expected to work for values between
    1 and 3999.
    
    Args:
        num (int): integer value to be converted to Roman numeral
    
    Returns:
        str: Roman numeral representation of integer
    """
    if not 1 <= num <= 3999:
        raise ValueError("number not between 1 and 3999 (%s)", num)

    numerals = {
        "M": 1000,
        "CM": 900,
        "D": 500,
        "CD": 400,
        "C": 100,
        "XC": 90,
        "L": 50,
        "XL": 40,
        "X": 10,
        "IX": 9,
        "V": 5,
        "IV": 4,
        "I": 1
    }

    def find_next_numeral(rem: int) -> dict:
        for key in numerals:
            if rem - numerals[key] >= 0:
                return key, numerals[key]

    res = []
    rem = num
    while rem > 0:
        next_numeral, next_int = find_next_numeral(rem)
        res.append(next_numeral)
        rem -= next_int

    return "".join(res)
